==> humphrey-0.1.0.crate: humphrey-0.1.0/src/http/mime.rs <==
/// Represents a MIME type as used in the `Content-Type` header.
#[derive(Clone, Copy)]
pub enum MimeType {
    TextCss,
    TextHtml,
    TextJavaScript,
    TextPlain,
    ImageBmp,
    ImageGif,
    ImageJpeg,
    ImagePng,
    ImageWebp,
    ImageSvg,
    ImageIcon,
    ApplicationOctetStream,
    ApplicationJson,
    ApplicationPdf,
    ApplicationZip,
    VideoMp4,
    VideoOgg,
    VideoWebm,
    FontTtf,
    FontOtf,
    FontWoff,
    FontWoff2,
}

impl MimeType {
    /// Converts from a file extension without the `.` to the enum variant.
    /// If the MIME type cannot be inferred from the extension, returns `MimeType::ApplicationOctetStream`.
    pub fn from_extension(extension: &str) -> Self {
        match extension {
            "css" => MimeType::TextCss,
            "html" => MimeType::TextHtml,
            "htm" => MimeType::TextHtml,
            "js" => MimeType::TextJavaScript,
            "txt" => MimeType::TextPlain,
            "bmp" => MimeType::ImageBmp,
            "gif" => MimeType::ImageGif,
            "jpeg" => MimeType::ImageJpeg,
            "jpg" => MimeType::ImageJpeg,
            "png" => MimeType::ImagePng,
            "webp" => MimeType::ImageWebp,
            "svg" => MimeType::ImageSvg,
            "ico" => MimeType::ImageIcon,
            "json" => MimeType::ApplicationJson,
            "pdf" => MimeType::ApplicationPdf,
            "zip" => MimeType::ApplicationZip,
            "mp4" => MimeType::VideoMp4,
            "ogv" => MimeType::VideoOgg,
            "webm" => MimeType::VideoWebm,
            "ttf" => MimeType::FontTtf,
            "otf" => MimeType::FontOtf,
            "woff" => MimeType::FontWoff,
            "woff2" => MimeType::FontWoff2,
            _ => MimeType::ApplicationOctetStream,
        }
    }
}

impl Into<String> for MimeType {
    fn into(self) -> String {
        match self {
            MimeType::TextCss => "text/css",
            MimeType::TextHtml => "text/html",
            MimeType::TextJavaScript => "text/javascript",
            MimeType::TextPlain => "text/plain",
            MimeType::ImageBmp => "image/bmp",
            MimeType::ImageGif => "image/gif",
            MimeType::ImageJpeg => "image/jpeg",
            MimeType::ImagePng => "image/png",
            MimeType::ImageWebp => "image/webp",
            MimeType::ImageSvg => "image/svg+xml",
            MimeType::ImageIcon => "image/vnd.microsoft.icon",
            MimeType::ApplicationOctetStream => "application/octet-stream",
            MimeType::ApplicationJson => "application/json",
            MimeType::ApplicationPdf => "application/pdf",
            MimeType::ApplicationZip => "application/zip",
            MimeType::VideoMp4 => "video/mp4",
            MimeType::VideoOgg => "video/ogg",
            MimeType::VideoWebm => "video/webm",
            MimeType::FontTtf => "font/ttf",
            MimeType::FontOtf => "font/otf",
            MimeType::FontWoff => "font/woff",
            MimeType::FontWoff2 => "font/woff2",
        }
        .to_string()
    }
}

==> humphrey-0.1.3.crate: humphrey-0.1.3/src/http/mime.rs <==
/// Represents a MIME type as used in the `Content-Type` header.
#[derive(Clone, Copy)]
pub enum MimeType {
    TextCss,
    TextHtml,
    TextJavaScript,
    TextPlain,
    ImageBmp,
    ImageGif,
    ImageJpeg,
    ImagePng,
    ImageWebp,
    ImageSvg,
    ImageIcon,
    ApplicationOctetStream,
    ApplicationJson,
    ApplicationPdf,
    ApplicationZip,
    VideoMp4,
    VideoOgg,
    VideoWebm,
    FontTtf,
    FontOtf,
    FontWoff,
    FontWoff2,
}

impl MimeType {
    /// Converts from a file extension without the `.` to the enum variant.
    /// If the MIME type cannot be inferred from the extension, returns `MimeType::ApplicationOctetStream`.
    pub fn from_extension(extension: &str) -> Self {
        match extension {
            "css" => MimeType::TextCss,
            "html" => MimeType::TextHtml,
            "htm" => MimeType::TextHtml,
            "js" => MimeType::TextJavaScript,
            "txt" => MimeType::TextPlain,
            "bmp" => MimeType::ImageBmp,
            "gif" => MimeType::ImageGif,
            "jpeg" => MimeType::ImageJpeg,
            "jpg" => MimeType::ImageJpeg,
            "png" => MimeType::ImagePng,
            "webp" => MimeType::ImageWebp,
            "svg" => MimeType::ImageSvg,
            "ico" => MimeType::ImageIcon,
            "json" => MimeType::ApplicationJson,
            "pdf" => MimeType::ApplicationPdf,
            "zip" => MimeType::ApplicationZip,
            "mp4" => MimeType::VideoMp4,
            "ogv" => MimeType::VideoOgg,
            "webm" => MimeType::VideoWebm,
            "ttf" => MimeType::FontTtf,
            "otf" => MimeType::FontOtf,
            "woff" => MimeType::FontWoff,
            "woff2" => MimeType::FontWoff2,
            _ => MimeType::ApplicationOctetStream,
        }
    }
}

impl From<MimeType> for String {
    fn from(val: MimeType) -> Self {
        match val {
            MimeType::TextCss => "text/css",
            MimeType::TextHtml => "text/html",
            MimeType::TextJavaScript => "text/javascript",
            MimeType::TextPlain => "text/plain",
            MimeType::ImageBmp => "image/bmp",
            MimeType::ImageGif => "image/gif",
            MimeType::ImageJpeg => "image/jpeg",
            MimeType::ImagePng => "image/png",
            MimeType::ImageWebp => "image/webp",
            MimeType::ImageSvg => "image/svg+xml",
            MimeType::ImageIcon => "image/vnd.microsoft.icon",
            MimeType::ApplicationOctetStream => "application/octet-stream",
            MimeType::ApplicationJson => "application/json",
            MimeType::ApplicationPdf => "application/pdf",
            MimeType::ApplicationZip => "application/zip",
            MimeType::VideoMp4 => "video/mp4",
            MimeType::VideoOgg => "video/ogg",
            MimeType::VideoWebm => "video/webm",
            MimeType::FontTtf => "font/ttf",
            MimeType::FontOtf => "font/otf",
            MimeType::FontWoff => "font/woff",
            MimeType::FontWoff2 => "font/woff2",
        }
        .to_string()
    }
}
